setConstructorS3("AromaUnitGcContentFile", function(...) {
  this <- extend(AromaUnitTabularBinaryFile(...), "AromaUnitGcContentFile");

  # Parse attributes (all subclasses must call this in the constructor).
  if (!is.null(this$.pathname))
    setAttributesByTags(this);

  this;
})


setMethodS3("getFilenameExtension", "AromaUnitGcContentFile", function(static, ...) {
  "ugc";
}, static=TRUE, protected=TRUE);


setMethodS3("getExtensionPattern", "AromaUnitGcContentFile", function(static, ...) {
  "[.](ugc)$";
}, static=TRUE, protected=TRUE)


setMethodS3("getColumnNames", "AromaUnitGcContentFile", function(this, ...) {
  "gcContent";
})


setConstructorS3("AromaUgcFile", function(...) {
  this <- extend(AromaUnitGcContentFile(...), "AromaUgcFile");
  # Parse attributes (all subclasses must call this in the constructor).
  if (!is.null(this$.pathname))
    setAttributesByTags(this);

  this;
})


############################################################################
# HISTORY:
# 2009-03-22
# o Created from AromaUflFile.R.
############################################################################
